@@ -9,8 +9,6 @@ import sys
 import textwrap
 import time
 
-import sys
-import subprocess
 from cloudmesh.burn.image import Image
 from cloudmesh.burn.sdcard import SDCard
 from cloudmesh.burn.usb import USB
@@ -19,18 +17,17 @@ from cloudmesh.burn.util import os_is_mac
 from cloudmesh.burn.util import os_is_pi
 from cloudmesh.burn.util import os_is_windows
 from cloudmesh.common.JobScript import JobScript
-from cloudmesh.common.Shell import Shell
 from cloudmesh.common.StopWatch import StopWatch
 from cloudmesh.common.Tabulate import Printer
 from cloudmesh.common.console import Console
+from cloudmesh.common.systeminfo import get_platform
 from cloudmesh.common.util import banner
 from cloudmesh.common.util import path_expand
+from cloudmesh.common.util import readfile
 from cloudmesh.common.util import writefile
-from cloudmesh.common.util import yn_choice
 from cloudmesh.common.util import sudo_readfile
 from cloudmesh.common.util import sudo_writefile
-from cloudmesh.common.systeminfo import get_platform
-from cloudmesh.common.util import readfile
+from cloudmesh.common.util import yn_choice
 
 
 # def dmesg():
@@ -50,16 +47,19 @@ def gen_strong_pass():
         string.punctuation
     return ''.join(random.choice(password_characters) for i in range(length))
 
+
 def windows_not_supported(f):
-    def wrapper(*args,**kwargs):
+    def wrapper(*args, **kwargs):
         host = get_platform()
         if host == "windows":
             Console.error("Not supported on windows")
             return ""
         else:
             return f(*args, **kwargs)
+
     return wrapper
 
+
 # noinspection PyPep8
 class Burner(object):
 
@@ -82,47 +82,68 @@ class Burner(object):
         """
         This method checks what configurations are placed on the PI se card
 
-        @param device:
-        @type device:
-        @return:
-        @rtype:
+        :param device:
+        :type device:
+        :return:
+        :rtype:
         """
 
         data = {
             "ssh": None,
             "hostname": None,
             "ip": None,
-            "password": None,
-            "shadow": None,
             "wifi": None,
             "psk": None,
             "ssid": None,
-            "wifipassword": None
+            "auth_key": None
         }
 
-        card = SDCard()
+        host = get_platform()
 
+        if host == "windows":
+            Console.error("Not yet implemented for this OS")
+            return ""
+
+        card = SDCard(host=host)
         # ssh
 
         try:
-            self.mount(device)
-            data["ssh"] = os.path.exists(card.boot_volume)
+            data["ssh"] = \
+                os.path.exists(f'{card.boot_volume}/ssh') or \
+                os.path.exists(f'{card.root_volume}/etc/systemd/system/sshd.service')
         except Exception as e:
             data["ssh"] = str(e)
+
+        # auth_key
+
+        try:
+            data["auth_key"] = \
+                os.path.exists(f'{card.root_volume}/home/pi/.ssh/authorized_keys')
+            if data["auth_key"]:
+                content = readfile(f"{card.root_volume}/home/pi/.ssh/authorized_keys")
+                data["auth_key"] = content.split()[-1]
+        except Exception as e:
+            data["auth_key"] = str(e)
+
         # hostname
 
-        content = readfile(f"{card.root_volume}/etc/hostname").strip()
-        data['hostname'] = content
+        try:
+            content = readfile(f"{card.root_volume}/etc/hostname").strip()
+            data['hostname'] = content
+        except Exception as e:
+            data["hostname"] = str(e)
 
         # ip
 
-        data["ip"] = "not yet implemented"
-
-        # passwod
-
-        data["password"] = "not yet implemented"
-
-        data["shadow"] = os.path.exists(f"{card.boot_volume}/etc/shadow")
+        try:
+            content = readfile(f"{card.root_volume}/etc/dhcpcd.conf")
+            for line in content.splitlines():
+                if line.startswith('static ip_address='):
+                    data['ip'] = line[18:]
+            if data['ip'] is None:
+                data['ip'] = 'False'
+        except Exception as e:
+            data["ip"] = str(e)
 
         # wifi
 
@@ -132,36 +153,34 @@ class Burner(object):
 
             if data["wifi"]:
                 lines = readfile(location).splitlines()
-
                 for line in lines:
-                    for tag in ["ssid", "wifipassword", "psk"]:
-                        if f"{tag} =" in line:
-                            data[tag] = line.split("{tag} =")[1]
+                    for tag in ["ssid", "psk"]:
+                        if f'{tag}=' in line:
+                            data[tag] = line.split(f'{tag}=')[1].replace('"', "")
 
             else:
                 data["wifi"] = False
                 data["ssid"] = None
-                data["wifipassword"] = None
+                data["psk"] = None
 
-        except Exception as e:
+        except Exception as e:  # noqa: F841
 
             data["wifi"] = False
             data["ssid"] = None
-            data["wifipasswd"] = None
+            data["psk"] = None
 
         banner("Card Check")
         print(Printer.attribute(
             data,
+            sort_keys=False,
             order=[
-                "ssh",
                 "hostname",
                 "ip",
-                "password",
-                "shadow",
+                "ssh",
+                "auth_key",
                 "wifi",
                 "psk",
-                "ssid",
-                "wifipassword"
+                "ssid"
             ]
         ))
 
@@ -176,20 +195,43 @@ class Burner(object):
             Console.error("This command can only be run on a PI")
         else:
             if action == "check":
-                Console.error("To be implemented")
-
-                command = f"sudo rpi-eeprom-update"
+                command = 'sudo apt update'
                 print(command)
+                print()
                 os.system(command)
-
-                os.system ("vcgencmd bootloader_version")
-
+                print()
+                command = 'sudo apt install rpi-eeprom'
+                print(command)
+                print()
+                os.system(command)
+                print()
+                command = "sudo rpi-eeprom-update"
+                print(command)
+                print()
+                os.system(command)
+                print()
+                os.system("vcgencmd bootloader_version")
+                print()
                 print("For more information see:")
                 print()
                 print("* https://www.raspberrypi.org/documentation/hardware/raspberrypi/booteeprom.md")
                 print()
             elif action == "update":
-                os.system("sudo rpi-eeprom-update -a")
+                command = 'sudo apt update'
+                print(command)
+                print()
+                os.system(command)
+                print()
+                command = 'sudo apt install rpi-eeprom'
+                print(command)
+                print()
+                os.system(command)
+                print()
+                command = "sudo rpi-eeprom-update -a"
+                print(command)
+                print()
+                os.system(command)
+                print()
                 os.system("sudo reboot")
 
     @windows_not_supported
@@ -206,11 +248,11 @@ class Burner(object):
         """
         Installs /usr/local/bin/pishrink.sh
         Installes parted
-        @return:
-        @rtype:
+        :return:
+        :rtype:
         """
 
-        if os_is_linux():
+        if os_is_linux() or os_is_pi():
             banner("Installing pishrink.sh into /usr/local/bin")
             script = \
                 """
@@ -244,8 +286,7 @@ class Burner(object):
     def copy(self, device=None, from_file="latest"):
         if device is None:
             Console.error("Device must have a value")
-        self.burn_sdcard(from_file, device)
-
+        self.burn_sdcard(image=from_file, device=device)
 
     @windows_not_supported
     def info(self, print_stdout=True):
@@ -316,7 +357,45 @@ class Burner(object):
 
         # print ('\n'.join(sorted(devices)))
 
-        details = USB.get_from_dmesg()
+        if os_is_mac():
+
+            import plistlib
+            external = subprocess.check_output("diskutil list -plist external".split(" "))
+
+            r = dict(plistlib.loads(external))
+
+            details = []
+
+            if len(r['AllDisksAndPartitions']) == 0:
+                Console.error("No partition found")
+                return ""
+
+            for partition in r['AllDisksAndPartitions'][0]['Partitions']:
+
+                if 'MountPoint' not in partition:
+                    partition['MountPoint'] = None
+                if partition['Content'] == 'Linux':
+                    partition['Content'] = 'ext4'
+                elif partition['Content'] == 'Windows_FAT_32':
+                    partition['Content'] = 'FAT32'
+
+                entry = {
+                    "dev": f"/dev/{partition['DeviceIdentifier']}",
+                    "active": None,
+                    "info": partition['MountPoint'],
+                    "readable": None,
+                    "formatted": partition['Content'],
+                    "empty": None,
+                    "size": partition['Size'],
+                    "direct-access": None,
+                    "removable": None,
+                    "writeable":
+                        'VolumeName' in partition and partition['VolumeName'] == 'boot'
+                }
+                details.append(entry)
+
+        else:
+            details = USB.get_from_dmesg()
 
         if print_stdout:
             banner("SD Cards Found")
@@ -419,54 +498,52 @@ class Burner(object):
         return res[1]
 
     @windows_not_supported
-    def burn_sdcard(self, tag="latest-lite", device=None, blocksize="4M"):
+    def burn_sdcard(self, image=None, tag=None, device=None, blocksize="4M"):
         """
         Burns the SD Card with an image
 
-        :param image: Image object to use for burning
+        :param image: Image object to use for burning (used by copy)
         :type image: str
+        :param tag: tag object used for burning (used by sdcard)
+        :type tag: str
         :param device: Device to burn to, e.g. /dev/sda
         :type device: str
         :param blocksize: the blocksize used when writing, default 4M
         :type blocksize: str
         """
+        if image and tag:
+            Console.error("Implementation error, burn_sdcard can't have image "
+                          "and tag.")
+            return ""
 
         Console.info("Burning...")
-        image = Image().find(tag=tag)
+        if image is not None:
+            image_path = image
+        else:
+            image = Image().find(tag=tag)
 
-        if image is None:
-            Console.error("No matching image found.")
-            return ""
-        elif len(image) > 1:
-            Console.error("Too manay images found")
-            print(Printer.write(image,
-                                order=["tag", "version"],
-                                header=["Tag", "Version"]))
-            return ""
+            if image is None:
+                Console.error("No matching image found.")
+                return ""
+            elif len(image) > 1:
+                Console.error("Too many images found")
+                print(Printer.write(image,
+                                    order=["tag", "version"],
+                                    header=["Tag", "Version"]))
+                return ""
 
-        image = image[0]
+            image = image[0]
 
-        image_path = Image().directory + "/" + Image.get_name(image["url"]) + ".img"
+            image_path = Image().directory + "/" + Image.get_name(image["url"]) + ".img"
 
-        if os_is_pi():
-
-            command = f"sudo dd bs={blocksize} if={image_path} of={device}"
-
-            result = subprocess.getoutput(command)
-
-            if "failed to open" in result:
-                Console.error("The image could not be found")
-                sys.exit(1)
-        elif os_is_linux():
+        if os_is_linux() or os_is_pi():
 
             print(image_path)
             print(device)
             print(blocksize)
             if device is None:
-                # or device == "none":
                 Console.error("Please specify a device")
-
-            # find device
+                return
 
             command = f"dd if={image_path} |" \
                       f" pv -w 80 |" \
@@ -477,6 +554,19 @@ class Burner(object):
         else:
             raise NotImplementedError("Only implemented to be run on a PI")
 
+    def mac(self, hostnames=None):
+        """
+        Sets the hostname for which we probe the MAC addresses
+
+        :param hostname: the hostname
+        :type hostname: str
+        """
+        self.hostnames = hostnames
+
+        print(hostnames)
+        Console.error("Not yet implemented")
+        return ""
+
     @windows_not_supported
     def set_hostname(self, hostname):
         """
@@ -489,10 +579,8 @@ class Burner(object):
         :type mountpoint: str
         """
         self.hostname = hostname
-        if os_is_pi():
+        if os_is_pi() or os_is_linux():
             card = SDCard()
-        elif os_is_linux():
-            card = SDCard(card_os="linux")
         else:
             raise NotImplementedError
 
@@ -525,6 +613,7 @@ class Burner(object):
             print('127.0.1.1 ' + hostname + '\n')
 
         # Adds the ip and hostname to /etc/hosts if it isn't already there.
+
     def add_to_hosts(self, ip):
         # with open('/etc/hosts', 'r') as host_file:
         #     hosts = host_file.readlines()
@@ -557,7 +646,7 @@ class Burner(object):
     def set_static_ip(self, ip, iface="eth0", mask="24"):
         """
         Sets the static ip on the sd card for the specified interface
-        Also writes to master hosts file for easy access
+        Also writes to manager hosts file for easy access
 
         :param ip: ips address
         :type ip: str
@@ -572,12 +661,11 @@ class Burner(object):
         :rtype:
         """
         # TODO:
-        # router_ip statically set to default ip configured with cms bridge create. Rewrite to consider the IP of the master on iface
+        # router_ip statically set to default ip configured with cms bridge
+        # create. Rewrite to consider the IP of the manager on iface
 
-        if os_is_pi():
+        if os_is_pi() or os_is_linux():
             card = SDCard()
-        elif os_is_linux():
-            card = SDCard(card_os="linux")
         else:
             raise NotImplementedError
 
@@ -615,12 +703,13 @@ class Burner(object):
         sudo_writefile(f'{mountpoint}/etc/dhcpcd.conf', '\n'.join(curr_config))
 
     # TODO:
-    # Deprecated function as dhcpcd.conf is the recommended file for configuring static network configs. Should we keep this?
+    # Deprecated function as dhcpcd.conf is the recommended file for
+    # configuring static network configs. Should we keep this?
     #
     # def set_static_ip2(self, ip, mountpoint, iface="eth0", mask="16"):
     #     """
     #     Sets the static ip on the sd card for the specified interface
-    #     Also writes to master hosts file for easy access
+    #     Also writes to manager hosts file for easy access
 
     #     :param ip: ips address
     #     :type ip: str
@@ -666,7 +755,7 @@ class Burner(object):
 
     #         sudo_writefile('/etc/hosts', config)
 
-    #     # Add static IP and hostname to master's hosts file and configure worker with static IP
+    #     # Add static IP and hostname to manager's hosts file and configure worker with static IP
     #     if not self.dryrun:
     #         add_to_hosts(ip)
 
@@ -717,10 +806,8 @@ class Burner(object):
         """
         # copy file on burner computer ~/.ssh/id_rsa.pub into
         #   mountpoint/home/pi/.ssh/authorized_keys
-        if os_is_pi():
+        if os_is_pi() or os_is_linux():
             card = SDCard()
-        elif os_is_linux():
-            card = SDCard(card_os="linux")
         else:
             raise NotImplementedError
 
@@ -734,43 +821,48 @@ class Burner(object):
         Mounts the current SD card
         """
         host = host or get_platform()
-        card = SDCard(card_os=card_os,host=host)
-        dmesg = USB.get_from_dmesg()
+        card = SDCard(card_os=card_os, host=host)
 
-        #TODO Need a better way to itentify which sd card to use for mounting
-        # instead of iterating over all of them
+        if host in ['linux', "raspberry"]:
+            dmesg = USB.get_from_dmesg()
 
-        if not self.dryrun:
-            self.system('sudo sync')  # flush any pending/in-process writes
+            # TODO Need a better way to itentify which sd card to use for mounting
+            # instead of iterating over all of them
 
-            for usbcard in dmesg:
+            if not self.dryrun:
+                self.system('sudo sync')  # flush any pending/in-process writes
 
-                dev = device or usbcard['dev']
-                print(dev)
-                sd1 = f"{dev}1"
-                sd2 = f"{dev}2"
-                try:
-                    if os.path.exists(sd1):
-                        Console.ok(f"mounting {sd1} {card.boot_volume}")
-                        self.system(f"sudo mkdir -p {card.boot_volume}")
-                        self.system(f"sudo mount -t vfat {sd1} {card.boot_volume}")
-                except Exception as e:
-                    print(e)
-                try:
-                    if os.path.exists(sd2):
-                        Console.ok(f"mounting {sd2} {card.root_volume}")
-                        self.system(f"sudo mkdir -p {card.root_volume}")
-                        self.system(f"sudo mount -t ext4 {sd2} {card.root_volume}")
-                except Exception as e:
-                    print(e)
+                for usbcard in dmesg:
 
-        #Keeping in case this was needed. Worked without it in testing.
-        #elif os_is_pi():
+                    dev = device or usbcard['dev']
+                    print(dev)
+                    sd1 = f"{dev}1"
+                    sd2 = f"{dev}2"
+                    try:
+                        if os.path.exists(sd1):
+                            Console.ok(f"mounting {sd1} {card.boot_volume}")
+                            self.system(f"sudo mkdir -p {card.boot_volume}")
+                            self.system(f"sudo mount -t vfat {sd1} {card.boot_volume}")
+                    except Exception as e:
+                        print(e)
+                    try:
+                        if os.path.exists(sd2):
+                            Console.ok(f"mounting {sd2} {card.root_volume}")
+                            self.system(f"sudo mkdir -p {card.root_volume}")
+                            self.system(f"sudo mount -t ext4 {sd2} {card.root_volume}")
+                    except Exception as e:
+                        print(e)
+            else:
+                Console.error("Not yet implemnted for your OS")
+                return ""
+
+        # Keeping in case this was needed. Worked without it in testing.
+        # elif os_is_pi():
         #    if not self.dryrun:
-                # wait for the OS to detect the filesystems
-                # in burner.info(), formatted will be true if the card has
-                #        FAT32
-                #   filesystems on it
+        # wait for the OS to detect the filesystems
+        # in burner.info(), formatted will be true if the card has
+        #        FAT32
+        #   filesystems on it
         #        counter = 0
         #        max_tries = 5
         #        b = Burner()
@@ -800,35 +892,55 @@ class Burner(object):
         if not self.dryrun:
             self.system('sudo sync')  # flush any pending/in-process writes
 
-            os.system(f"sudo umount {card.boot_volume}")
-            time.sleep(3)
-            os.system(f"sudo umount {card.root_volume}")
+            if host in ['linux', 'raspberry']:
 
-            time.sleep(3)
+                Console.ok(f"unmounting {card.boot_volume}")
+                os.system(f"sudo umount {card.boot_volume}")
+                time.sleep(3)
+                Console.ok(f"unmounting  {card.root_volume}")
+                os.system(f"sudo umount {card.root_volume}")
 
-            rm = [f"sudo rmdir {card.boot_volume}",
-                  f"sudo rmdir {card.root_volume}"]
+                time.sleep(3)
 
-            for command in rm:
-                print(rm)
-                os.system(command)
+                rm = [f"sudo rmdir {card.boot_volume}",
+                      f"sudo rmdir {card.root_volume}"]
+
+                for command in rm:
+                    os.system(command)
+            elif host == "macos":
+
+                Console.ok(f"unmounting {card.boot_volume}")
+                os.system(f"diskutil umount {card.boot_volume}")
+
+            else:
+                Console.error("Not yet implemnted for your OS")
+                return ""
 
     @windows_not_supported
     def enable_ssh(self):
         """
         Enables ssh on next boot of sd card
         """
-        if os_is_pi():
-            card = SDCard(card_os="raspberry")
-            command = f'sudo touch {card.boot_volume}/ssh'
-            self.system(command)
-        elif os_is_linux():
-            card = SDCard(card_os="raspberry")
-            command = f"sudo touch {card.boot_volume}/ssh"
-            self.system(command)
+        host = get_platform()
 
+        if host == "windows":
+            Console.error("Not yet implemented for this OS")
+            return ""
+
+        if host in ['raspberry', "linux"]:
+            sudo = True
         else:
-            raise NotImplementedError
+            sudo = False
+
+        card = SDCard(card_os="raspberry", host=host)
+        if sudo:
+            command = f'sudo touch {card.boot_volume}/ssh'
+        else:
+            command = f'touch {card.boot_volume}/ssh'
+
+        self.system(command)
+
+        return ""
 
     # IMPROVE
 
@@ -963,7 +1075,7 @@ class Burner(object):
         # this up later?
 
         new_lines = textwrap.dedent('''
-                    # FIX298-START: Fix permissions for .ssh directory 
+                    # FIX298-START: Fix permissions for .ssh directory
                     if [ -d "/home/pi/.ssh" ]; then
                         chown pi:pi /home/pi/.ssh
                         chmod 700 /home/pi/.ssh
@@ -996,7 +1108,9 @@ class Burner(object):
     def configure_wifi(self,
                        ssid,
                        psk=None,
-                       interactive=False):
+                       card_os='raspberry',
+                       host=None,
+                       country=None):
         """
         Sets the wifi. Only works for psk based wifi
 
@@ -1004,45 +1118,52 @@ class Burner(object):
         :type ssid: str
         :param psk: the psk
         :type psk: str
-        :param interactive: true if you like to run it interactively
-        :type interactive: bool
+        :param card_os: the os on the sdcard
+        :type card_os: str
+        :param host: the machine os running the command
+        :type host: str
+        :param country: two digit country code for rf settings
+        :type country: str
         """
-        if psk is not None:
+
+        country = country or 'US'
+
+        if psk:
             wifi = textwrap.dedent("""\
-                    ctrl_interface=DIR=/var/run/wpa_supplicant GROUP=netdev 
-                    update_config=1 
-                    country=US
+                    ctrl_interface=DIR=/var/run/wpa_supplicant GROUP=netdev
+                    update_config=1
+                    country={country}
 
                     network={{
                             ssid=\"{network}\"
-                            psk=\"{pwd}\"
-                            key_mgmt=WPA-PSK
-                    }}""".format(network=ssid, pwd=psk))
+                            psk=\"{psk}\"
+                    }}""".format(network=ssid, psk=psk, country=country))
         else:
             wifi = textwrap.dedent("""\
-                    ctrl_interface=DIR=/var/run/wpa_supplicant GROUP=netdev 
-                    update_config=1 
-                    country=US
+                    ctrl_interface=DIR=/var/run/wpa_supplicant GROUP=netdev
+                    update_config=1
+                    country={country}
 
                     network={{
                             ssid=\"{network}\"
                             key_mgmt=NONE
-                    }}""".format(network=ssid))
+                    }}""".format(network=ssid, country=country))
 
-        # Per fix provided by Gregor, we use this path to get around rfkill block on boot
         card = SDCard(card_os=card_os, host=host)
         path = f"{card.boot_volume}/wpa_supplicant.conf"
         if self.dryrun:
             print("DRY RUN - skipping:")
             print("Writing wifi ssid:{} psk:{} to {}".format(ssid,
                                                              psk, path))
-            return
+            return ""
 
-        # with open(path, 'w') as f:
-        #     f.write(wifi)
-        sudo_writefile(path, wifi)
+        if os_is_mac():
+            writefile(path, wifi)
+        else:
+            sudo_writefile(path, wifi)
+
+        return ""
 
-    # TODO
     @windows_not_supported
     def format_device(self, device='dev/sdX', hostname=None, title="UNTITLED"):
         """
@@ -1086,10 +1207,7 @@ class Burner(object):
         :param hostname: the hostname
         :type hostname: str
         """
-        if os_is_pi():
-            Console.error("Not yet implemented")
-
-        elif os_is_linux():
+        if os_is_linux() or os_is_pi():
 
             banner(f"load {device}")
             os.system(f"sudo eject -t {device}")
@@ -1321,7 +1439,8 @@ class MultiBurner(object):
                         choice = input("Please use [y/n] ")
                     if choice == 'n':
                         break
-                input('Insert next card and press enter...')
+                    elif choice == 'y':
+                        input('Insert next card and press enter...')
                 print('Burning next card...')
                 print()
 
@@ -1371,9 +1490,9 @@ class MultiBurner(object):
         :return:
         :rtype:
         """
-        #TODO
+        # TODO
         card = SDCard()
-        boot_volume = card.boot_volume
+        # boot_volume = card.boot_volume
         root_volume = card.root_volume
         if key is None:
             key = '~/.ssh/id_rsa.pub'
