@@ -7,6 +7,8 @@ from cloudmesh.burn.burner import gen_strong_pass
 from cloudmesh.burn.image import Image
 from cloudmesh.burn.network import Network
 from cloudmesh.burn.util import os_is_pi
+from cloudmesh.burn.util import os_is_mac
+from cloudmesh.burn.util import os_is_linux
 from cloudmesh.common.StopWatch import StopWatch
 from cloudmesh.common.Tabulate import Printer
 from cloudmesh.common.parameter import Parameter
@@ -14,6 +16,7 @@ from cloudmesh.common.util import Console
 from cloudmesh.shell.command import PluginCommand
 from cloudmesh.shell.command import command
 from cloudmesh.shell.command import map_parameters
+# from cloudmesh.common.debug import VERBOSE
 
 
 class BurnCommand(PluginCommand):
@@ -25,6 +28,7 @@ class BurnCommand(PluginCommand):
 
             Usage:
               burn firmware check
+              burn firmware update
               burn install
               burn load --device=DEVICE
               burn format --device=DEVICE
@@ -57,8 +61,9 @@ class BurnCommand(PluginCommand):
                        [--ip=IP]
                        [--key=KEY]
               burn enable ssh
-              burn wifi --ssid=SSID [--passwd=PASSWD] [-ni]
+              burn wifi --ssid=SSID [--passwd=PASSWD] [--country=COUNTRY]
               burn check [--device=DEVICE]
+              burn mac --hostname=HOSTNAME
 
             Options:
               -h --help              Show this screen.
@@ -128,6 +133,10 @@ class BurnCommand(PluginCommand):
 
                     checks if the firmware on the Pi is up to date
 
+                cms burn firmware update
+
+                    checks and updates the firmware on the Pi
+
                 cms burn install
 
                     installs a program to shring img files. THis is useful, after
@@ -224,10 +233,16 @@ class BurnCommand(PluginCommand):
 
                     this enables the ssh server once it is booted
 
-                cms burn wifi --ssid=SSID [--passwd=PASSWD] [-ni]
+                cms burn wifi --ssid=SSID [--passwd=PASSWD] [--country=COUNTRY]
 
                     this sets the wifi ssid and password afterthe card is created,
-                    copies, or sdcard is used
+                    copies, or sdcard is used.
+
+                    The option country option expects an ISO
+                    3166-1 two digit country code. The default is "US" and
+                    the option not required if suitable. See
+                    https://en.wikipedia.org/wiki/ISO_3166-1 for other
+                    countries.
 
                 cms burn check [--device=DEVICE]
 
@@ -266,7 +281,8 @@ class BurnCommand(PluginCommand):
                        "wifipassword",
                        "version",
                        "to",
-                       "os")
+                       "os",
+                       "country")
         # arguments.MOUNTPOINT = arguments["--mount"]
         arguments.FORMAT = arguments["--format"]
         arguments.FROM = arguments["--from"]
@@ -361,25 +377,32 @@ class BurnCommand(PluginCommand):
                 details,
                 order=['label', "local", "broadcast"],
                 header=["Label", "Local", "Broadcast"]
-                )
+            )
             )
             return ""
 
         elif arguments.wifi:
 
-            Console.error("This command is not yet implemented")
-            return ""
-
             password = arguments.passwd
             ssid = arguments.ssid
+            country = arguments.country
 
             if password is None:
-                password = getpass("Please enter the Wifi password; ")
+                password = getpass("Please enter the Wifi password or enter "
+                                   "for no password: ")
+
+            if os_is_mac():
+                host = "macos"
+            elif os_is_linux():
+                host = "linux"
+            elif os_is_pi():
+                host = "raspberry"
+            else:
+                Console.error("This command is not yet implemented for your OS")
+                return ""
+
+            burner.configure_wifi(ssid, psk=password, country=country, host=host)
 
-            StopWatch.stop("wifi")
-            # burner.configure_wifi(ssid, password)
-            StopWatch.stop("wifi")
-            StopWatch.status("wifi", True)
             return ""
 
         elif arguments.info:
@@ -406,7 +429,7 @@ class BurnCommand(PluginCommand):
             return ""
 
         elif arguments.sdcard:
-            arguments.TAG = arguments.TAG or ["latest"]
+            arguments.TAG = arguments.TAG or ["latest-lite"]
 
             execute("sdcard", burner.burn_sdcard(tag=arguments.TAG, device=arguments.device))
             return ""
@@ -421,6 +444,13 @@ class BurnCommand(PluginCommand):
                                               card_os=arguments.os))
             return ""
 
+        elif arguments.mac:
+
+            hostnames = Parameter.expand(arguments.hostname)
+
+            execute("mac", burner.mac(hostnames=hostnames))
+            return ""
+
         elif arguments.set:
 
             if arguments.hostname:
