@@ -2,12 +2,9 @@ import os
 from pathlib import Path
 
 from cloudmesh.common.Shell import Shell
-from cloudmesh.burn.util import os_is_linux
-from cloudmesh.burn.util import os_is_windows
-from cloudmesh.burn.util import os_is_mac
-from cloudmesh.burn.util import os_is_pi
-from cloudmesh.common.systeminfo import get_platform
 from cloudmesh.common.console import Console
+from cloudmesh.common.systeminfo import get_platform
+
 
 class SDCard:
 
@@ -18,7 +15,7 @@ class SDCard:
         :param os: the os that is part of the mount. Default: raspberry
         :type os: str
         :param host: the host on which we execute the command
-        :type host: possible values: raspeberry, darwin, linux
+        :type host: possible values: raspeberry, macos, linux
         """
         self.card_os = card_os or "raspberry"
         self.host = host or get_platform()
@@ -35,11 +32,9 @@ class SDCard:
         :rtype: str
         """
         user = os.environ.get('USER')
-        if self.card_os == "raspberry" and self.host == "darwin":
-            #return Path(f"/Volume/rootfs")
-            Console.error("Requires and ext4 writable file system."
-                          " Commercial solutions available.")
-            return "notimplemented"
+        if self.card_os == "raspberry" and self.host == "macos":
+            Console.error("Requires and ext4 writable file system. NOt supported by default.")
+            return Path("/Volumes/rootfs")
         elif self.host == 'linux':
             if "raspberry" in self.card_os:
                 return Path(f"/media/{user}/rootfs")
@@ -64,9 +59,9 @@ class SDCard:
         :rtype: str
         """
         user = os.environ.get('USER')
-        if self.host == "darwin":
+        if self.host == "macos":
             if "raspberry" in self.card_os:
-                return Path("/Volume/boot")
+                return Path("/Volumes/boot")
             elif "linux" in self.card_os:
                 return Path("/Volume/system-boot")
         elif self.host == "linux":
@@ -87,8 +82,8 @@ class SDCard:
         """
         List all file systems on the SDCard. This is for the PI rootfs and boot
 
-        @return: A dict representing the file systems on the SDCCards
-        @rtype: dict
+        :return: A dict representing the file systems on the SDCCards
+        :rtype: dict
         """
 
         r = Shell.run("mount -l").splitlines()
@@ -99,11 +94,11 @@ class SDCard:
         for line in r:
             if str(root_fs) in line or str(boot_fs) in line:
                 entry = \
-                    line.replace(" on ", "|")\
-                        .replace(" type ", "|")\
-                        .replace(" (", "|")\
-                        .replace(") [", "|")\
-                        .replace("]", "")\
+                    line.replace(" on ", "|") \
+                        .replace(" type ", "|") \
+                        .replace(" (", "|") \
+                        .replace(") [", "|") \
+                        .replace("]", "") \
                         .split("|")
                 print(entry)
                 detail = {
