@@ -36,7 +36,7 @@ class USB(object):
         """
         try:
             return self.vendors[vendor][product]
-        except Exception as e:
+        except Exception as e:  # noqa: F841
             return "unkown"
 
     def load_vendor_description(self):
@@ -56,24 +56,35 @@ class USB(object):
         data = {}
         product_id = None
         vendor_id = None
+        vendor = None
         content = self.get_vendor().splitlines()
         for line in content:
             try:
-                if line.startswith("#") or line.startswith("]") or line is None:
-                    pass
-                elif line.startswith("\t"):
+                other_devices = ['C', 'AT', 'HID', 'R', 'BIAS', 'PHY', 'HUT',
+                                 'L', 'HCC', 'VT']
+                other_dev = False
+                for dev in other_devices:
+                    if line.startswith(dev):
+                        other_dev = True
+
+                first_word = line.strip().split()[0]
+
+                if line.startswith("#") or line.startswith("]") or line is \
+                        None or other_dev:
+                    continue
+                elif not line.startswith("\t") and len(first_word) == 4:
+                    vendor_id, vendor = line.strip().split(" ", 1)
+                    data[vendor_id] = {}
+                elif line.startswith("\t") and len(first_word) == 4:
                     product_id, product = line.strip().split(" ", 1)
-                    print(vendor_id, product_id, product)
                     data[vendor_id][product_id] = {
                         'vendor_id': vendor_id,
                         'product_id': product_id,
                         'vendor': vendor,
                         'product': product
                     }
-                else:
-                    vendor_id, vendor = line.strip().split(" ", 1)
-                    data[vendor_id] = {}
-            except Exception as e:
+
+            except:
                 pass
         self.vendors = data
         return data
@@ -133,14 +144,11 @@ class USB(object):
         :return: list of dicts
         :rtype: list
         """
-
-        #
-        # in future we also look up the vendor
-        #
-        # v = USB()
-        # v.load_vendor_description()
-
-        # pprint (v.vendors)
+        try:
+            v = USB()
+            v.load_vendor_description()
+        except:
+            pass
 
         def h(d, a):
             v = hex(d[a])
@@ -157,8 +165,16 @@ class USB(object):
                 data.update(dev.dev.__dict__)
                 data['comment'] = lsusb[f"{dev.bus}-{dev.address}"]["comment"]
                 del data['configurations']
-                data["hVendor"] = h(data, "idVendor")
-                data["hProduct"] = h(data, "idProduct")
+                try:
+                    vendor = f'{data["idVendor"]:04x}'
+                    product = f'{data["idProduct"]:04x}'
+                    vendor_str = v.vendors[vendor][product]['vendor']
+                    device_str = v.vendors[vendor][product]['product']
+                    data["hVendor"] = vendor_str
+                    data["hProduct"] = device_str
+                except:
+                    data["hVendor"] = h(data, "idVendor")
+                    data["hProduct"] = h(data, "idProduct")
                 data["serach"] = "tbd"
                 details.append(data)
         return details
@@ -204,7 +220,7 @@ class USB(object):
                     'comment': ' '.join(content[4:])
                 }
                 all[f"{bus}-{addr}"] = data
-            except Exception as e:
+            except Exception as e:  # noqa: F841
                 pass
 
         return all
@@ -249,7 +265,10 @@ class USB(object):
                     details[key] = {}
                 details[key]["key"] = key
                 if "Attached SCSI removable disk" in comment:
-                    details[key]["removable"] = True
+                    try:
+                        details[key]["removable"] = True
+                    except:
+                        details[key]["removable"] = False
                 if "logical blocks:" in comment:
                     size = comment.split("blocks:")[1]
                     details[key]["size"] = size.strip().replace("(",
@@ -261,7 +280,9 @@ class USB(object):
                     details[key]["writeable"] = True
                 name = details[key]["name"] = device.replace("[", "").replace(
                     "]", "")
-                dev = details[key]["dev"] = f"/dev/{name}"
+                # TODO:
+                # This line was commented out previously, causing the program to fail. Why was this done?
+                details[key]["dev"] = f"/dev/{name}"
                 _fdisk = USB.fdisk(name)
                 details[key]['readable'] = "cannot open" in _fdisk
                 details[key]['empty'] = "linux" in _fdisk
@@ -303,7 +324,6 @@ class USB(object):
                         _get_attribute("write_protection:",
                                        _dmesg) is not "off",
                     'size': size,
-                    
                 })
         return details
         '''
